@@ -1,27 +1,15 @@
-#pragma once
 /*
 * Copyright 2016 Nu-book Inc.
 * Copyright 2016 ZXing authors
 * Copyright 2020 Axel Waggershauser
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*      http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
 */
+// SPDX-License-Identifier: Apache-2.0
+
+#pragma once
 
 #include "Point.h"
 #include "Quadrilateral.h"
 
-#include <array>
-
 namespace ZXing {
 
 /**
@@ -46,6 +34,7 @@ class PerspectiveTransform
 	static PerspectiveTransform UnitSquareTo(const QuadrilateralF& q);
 
 public:
+	PerspectiveTransform() = default;
 	PerspectiveTransform(const QuadrilateralF& src, const QuadrilateralF& dst);
 
 	/// Project from the destination space (grid of modules) into the image space (bit matrix)
