@@ -1,18 +1,7 @@
 /*
 * Copyright 2016 Nu-book Inc.
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*      http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
 */
+// SPDX-License-Identifier: Apache-2.0
 
 #include "ReadBarcode.h"
 
@@ -27,68 +16,57 @@
 struct ReadResult
 {
 	std::string format;
-	std::wstring text;
+	std::string text;
 	std::string error;
 	ZXing::Position position;
 };
 
-ReadResult readBarcodeFromImage(int bufferPtr, int bufferLength, bool tryHarder, std::string format)
+ReadResult readBarcodeFromImageView(ZXing::ImageView iv, bool tryHarder, const std::string& format)
 {
 	using namespace ZXing;
 	try {
 		DecodeHints hints;
 		hints.setTryHarder(tryHarder);
 		hints.setTryRotate(tryHarder);
+		hints.setTryInvert(tryHarder);
 		hints.setTryDownscale(tryHarder);
 		hints.setFormats(BarcodeFormatsFromString(format));
+		hints.setMaxNumberOfSymbols(1);
 
-		int width, height, channels;
-		std::unique_ptr<stbi_uc, void (*)(void*)> buffer(
-			stbi_load_from_memory(reinterpret_cast<const unsigned char*>(bufferPtr), bufferLength, &width, &height,
-								  &channels, 4),
-			stbi_image_free);
-		if (buffer == nullptr) {
-			return { "", L"", "Error loading image" };
-		}
-
-		auto result = ReadBarcode({buffer.get(), width, height, ImageFormat::RGBX}, hints);
-		if (result.isValid()) {
+		auto results = ReadBarcodes(iv, hints);
+		if (!results.empty()) {
+			auto& result = results.front();
 			return { ToString(result.format()), result.text(), "", result.position() };
 		}
 	}
 	catch (const std::exception& e) {
-		return { "", L"", e.what() };
+		return { "", "", e.what() };
 	}
 	catch (...) {
-		return { "", L"", "Unknown error" };
+		return { "", "", "Unknown error" };
 	}
 	return {};
 }
 
+ReadResult readBarcodeFromImage(int bufferPtr, int bufferLength, bool tryHarder, std::string format)
+{
+	using namespace ZXing;
+
+	int width, height, channels;
+	std::unique_ptr<stbi_uc, void (*)(void*)> buffer(
+		stbi_load_from_memory(reinterpret_cast<const unsigned char*>(bufferPtr), bufferLength, &width, &height, &channels, 4),
+		stbi_image_free);
+	if (buffer == nullptr) {
+		return {"", "", "Error loading image"};
+	}
+
+	return readBarcodeFromImageView({buffer.get(), width, height, ImageFormat::RGBX}, tryHarder, format);
+}
+
 ReadResult readBarcodeFromPixmap(int bufferPtr, int imgWidth, int imgHeight, bool tryHarder, std::string format)
 {
 	using namespace ZXing;
-	try {
-		DecodeHints hints;
-		hints.setTryHarder(tryHarder);
-		hints.setTryRotate(tryHarder);
-		hints.setTryDownscale(tryHarder);
-		hints.setFormats(BarcodeFormatsFromString(format));
-
-		auto result =
-			ReadBarcode({reinterpret_cast<uint8_t*>(bufferPtr), imgWidth, imgHeight, ImageFormat::RGBX}, hints);
-
-		if (result.isValid()) {
-			return { ToString(result.format()), result.text(), "", result.position() };
-		}
-	}
-	catch (const std::exception& e) {
-		return { "", L"", e.what() };
-	}
-	catch (...) {
-		return { "", L"", "Unknown error" };
-	}
-	return {};
+	return readBarcodeFromImageView({reinterpret_cast<uint8_t*>(bufferPtr), imgWidth, imgHeight, ImageFormat::RGBX}, tryHarder, format);
 }
 
 EMSCRIPTEN_BINDINGS(BarcodeReader)
@@ -116,8 +94,4 @@ EMSCRIPTEN_BINDINGS(BarcodeReader)
 
 	function("readBarcodeFromImage", &readBarcodeFromImage);
 	function("readBarcodeFromPixmap", &readBarcodeFromPixmap);
-
-	// obsoletes
-	function("readBarcode", &readBarcodeFromImage);
-	function("readBarcodeFromPng", &readBarcodeFromImage);
 }
